from . import translate

bl_info = {
    "name": "Fit Lattice vfxMed",
    "author": "Mark Kingsnorth",
    "version": (1, 8, 0),
    "blender": (2, 80, 0),
    "location": "View3D > Object > Fit Lattice",
    "description": "Creates a lattice and fits it to a mesh",
    "warning": "",
    "wiki_url": "",
    "category": "Mesh",
}

# To support reload properly, try to access a package var,
# if it's there, reload everything
if "bpy" in locals():
    import importlib

    importlib.reload(fit_lattice)
    print("Reloaded fit_lattice files")
else:
    from . import fit_lattice

    print("Imported fit_lattice")

import bpy
from bpy.types import PropertyGroup


class OBJECT_MT_FitLatticeButtonsSub(bpy.types.Menu):
    bl_label = "Fit Lattice"
    bl_idname = "FIT_LATTICE_MT_view3d_fit_lattice_menu_submenu"

    def draw(self, context):
        fit_lattice.fit_lattice_menu_func(self.layout)


def menu_func(self, context):
    self.layout.menu(OBJECT_MT_FitLatticeButtonsSub.bl_idname)


class OBJECT_OT_FitLatticeObject(PropertyGroup):
    fit_lattice_object_ref: bpy.props.PointerProperty(type=bpy.types.Object)


classes = [
    fit_lattice.MESH_OT_fit_lattice,
    fit_lattice.MESH_OT_remove_fit_lattice,
    OBJECT_MT_FitLatticeButtonsSub,
    OBJECT_OT_FitLatticeObject,
]


def register():
    from bpy.utils import register_class

    for cls in classes:
        register_class(cls)

    bpy.types.Object.fit_lattice_object_refs = bpy.props.CollectionProperty(
        type=OBJECT_OT_FitLatticeObject
    )

    bpy.types.VIEW3D_MT_object.append(menu_func)
    bpy.types.VIEW3D_MT_object_context_menu.append(menu_func)
    bpy.types.VIEW3D_MT_edit_mesh.append(menu_func)
    bpy.types.VIEW3D_MT_edit_mesh_context_menu.append(menu_func)

    fit_lattice.add_to_key_map()
    translate.register()


def unregister():
    fit_lattice.remove_from_key_map()

    bpy.types.VIEW3D_MT_edit_mesh_context_menu.remove(menu_func)
    bpy.types.VIEW3D_MT_edit_mesh.remove(menu_func)
    bpy.types.VIEW3D_MT_object_context_menu.remove(menu_func)
    bpy.types.VIEW3D_MT_object.remove(menu_func)

    del bpy.types.Object.fit_lattice_object_refs

    from bpy.utils import unregister_class

    for cls in reversed(classes):
        unregister_class(cls)
    translate.unregister()


if __name__ == "__main__":
    register()
